pilas.habilidades.PisaPlataformas

Package pilas :: Module habilidades :: Class PisaPlataformas |
[hide private]
[frames] | no frames]

# Class PisaPlataformas

source code

    object --+
             |
     Habilidad --+
                 |
                PisaPlataformas

Enseña al actor a pisar plataformas físicas.

Instance Methods | [hide private]
__init__(self, receptor) x.__init__(...) initializes x; see help(type(x)) for signature | source code
actualizar(self) | source code
eliminar(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### actualizar(self) | source code
Overrides: Habilidad.actualizar

### eliminar(self) | source code
Overrides: Habilidad.eliminar